VideoThumbKitPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • VideoThumbKitPlatform
Implementers

Constructors

VideoThumbKitPlatform()
Constructs a VideoThumbKitPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
thumbnailData({required String video, Map<String, String>? headers, ImageFormat imageFormat = ImageFormat.png, int maxHeight = 0, int maxWidth = 0, int timeMs = 0, int quality = 10}) Future<Uint8List?>
thumbnailDataWeb({required Uint8List videoBytes, num quality = 100}) Future<Uint8List?>
thumbnailFile({required String video, Map<String, String>? headers, String? thumbnailPath, ImageFormat imageFormat = ImageFormat.png, int maxHeight = 0, int maxWidth = 0, int timeMs = 0, int quality = 10}) Future<String?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance VideoThumbKitPlatform
The default instance of VideoThumbKitPlatform to use.
getter/setter pair